****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_t1t2_createcdf.sas  
*
* Created (mm/dd/yyyy): 12/27/2017
* Last modified: 02/12/19
* Version: 1.3
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
* 	This program will aggregate [runid]_censor_cida.sas7bdat and output CDF graphs
*
*  Program inputs:                                                                                   
* 	-&RUNID._censor_cida.sas7bdat
*
*  Program outputs:                                                                                                                                       
*
* PARAMETERS:
*
*  Programming Notes:                                                                                
*                                                                           
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials	   Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*	1.1		  06/05/18	   AP		Added UserStrata lookup to determine correct level
*									Changed &grp to &grps (DEV-1033)
*
*	1.2 	  12/26/18	   AP		Capatibility modifications for T5 report
*									Changed macro name from ms_createcdf to ms_t1t2_createcdf
*
*	1.3 	  02/12/19	   AP		Changed DP macro variable to prevent conflict with CC defined var
*
***************************************************************************************************;

%macro ms_t1t2_createcdf();

	%put =====> MACRO CALLED: ms_t1t2_createcdf v1.3;

/*--------------------------------------------------------------------------------------------*/
/* 1: Aggregate datasets																	  */
/*--------------------------------------------------------------------------------------------*/

	/*Determine appropriate level for continuous censdays_value*/
	data censorlevel;
		set userstrata;
		where tableID = "t&type.censor" and levelvars = 'censdays_value';
	run;
	%isdata(dataset=censorlevel);
	%if %eval(&nobs.=1) %then %do;
		proc sql noprint;
			select levelid into: censorlevel
			from censorlevel;
		quit;
	%end;
	%else %do;
		%put WARNING: Continuous censor days stratification not requested.;
		%let Output_CDF_KM = N;
		%goto exit; 
	%end;

		%if %length(&T1GroupList.) > 0 %then %do;
			/*for each Data Partner*/
			%do dps = 1 %to &num_dp;
		 		%let currentdp = %scan(&random_dpid_list.,&dps);

				/*do loop for RUNID1 and GROUP1*/
				%do grps = 1 %to &NUM_T1Groups.;
					%let RUNID = %scan(&T1runids, &grps.);
					%let group = %scan(&T1GroupList.,&grps);
				  	%if %sysfunc(exist(msoc.&RUNID._censor_cida))=0 %then %do;
						    %put WARNING: &RUNID._censor_cida. does not exist. Please confirm censor distribution output is requested.;
							%let Output_CDF_KM = N;
							%goto exit; 
				   %end;
				   %else %do;
				   	 	data censor_dp&dps._grp&grps.;
					 	   length combinegrouplabel $61;
					 	   set msoc.&RUNID._censor_cida
							  ;
						  	where group in ("&group.") and level = "&censorlevel.";
							combinegrouplabel = GROUP;						
					 	 run;
					 	PROC APPEND DATA = censor_dp&dps._grp&grps.  base = cida_censor force; run; /*Append datasets*/
					%end;
				%end; 
			%end; /*end of all runids within DP*/
		%end;
	
		/*Aggregate censored data for combined groups*/
		%if %length(&combinegroup1.) > 0 and %length(&combinegroup2.) > 0 %then %do;
			%do dps = 1 %to &num_dp.;
				%let currentdp = %scan(&random_dpid_list.,&dps);
					%do r = 1 %to %sysfunc(countw(&combinegroup1.));
						%put combiner  resolves to ==> &r.;
						%do c = 1 %to 2;
							%put combiner  resolves to ==> &&combinerun&c..;
							%let RUNID&c. = %scan(&&combinerun&c.., &r.);
							%let GROUP&c. = %scan(&&combinegroup&c.., &r.);
						%end;
						%if %sysfunc(exist(msoc.&RUNID1._censor_cida))=0 or %sysfunc(exist(msoc.&RUNID2._censor_cida))=0 %then %do;
					    	%put WARNING: &RUNID1_censor_cida. and/or &RUNID2._censor_cida. does not exist. Please confirm censor distribution output is requested.;
							%let Output_CDF_KM = N;
							%goto exit; 
			   			%end;
						%else %do;
							%do c = 1 %to 2;
								data combinecensor_&dps._&r._&c.;
									set msoc.&&RUNID&c.._censor_cida; 
									where group in ("&&GROUP&c..") and level = "&censorlevel.";
							 	run;
							%end;

							proc sql noprint;
								select combinedgroupname into: combinedgroupname
								from infolder.&groupfile.
								where group1 = "&group1." and group2 = "&group2.";
							quit;
							
							 data combinecensor_&dps._&r.;
							 	 length combinegrouplabel $61;
	  							 set  combinecensor_&dps._&r._1 combinecensor_&dps._&r._2; 
								 	 combinegrouplabel = "&combinedgroupname.";
							 run;
							 
							 proc means data =  combinecensor_&dps._&r. nway noprint;
							 	class combinegrouplabel censdays_value;
								var episodes &all_censor_criteria.;
								output out = combinecensor_&dps._&r. (drop = _:) sum=;
							run;

							PROC APPEND DATA = combinecensor_&dps._&r. base = combine_cida_censor force; run; /*Append datasets*/
				 		%end; /*end of processing data for each combined run*/
				%end; /*end of all combined groups within DP*/
			%end;	/*end of all DPS*/
		%end; /*end of process for combined groups*/	 
					

		/*Make one cida censor dataset*/
		data agg_cida_censor;			
			 set 
			  %if %sysfunc(exist(cida_censor)) %then %do;
				cida_censor (drop = group)
			  %end;
			 %if %sysfunc(exist(combine_cida_censor)) %then %do;
				combine_cida_censor
			 %end;
			 ;
			 length group $60;
			 group = combinegrouplabel;
		run;

	/*Clean up some work files*/
	proc datasets lib=work nowarn nolist;
		delete combinecensor_: censor_dp:; 
	quit;

/*--------------------------------------------------------------------------------------------*/
/* 2: Assign defaults and build macro variables and graph series statements					  */
/*--------------------------------------------------------------------------------------------*/

	/*order according to the input file*/
	data grouporder;
		length group $61;
	  	set infolder.&groupfile.;
	    	if not missing(group1) and not missing(group2) then do;
				group = combinedgroupname;
			end;
			else group = group1;
	run;
	
	proc sql;
		 create table _grouporder as 
		 select distinct a.group, b.order
		  from agg_cida_censor a, grouporder b
		  where a.group = b.group
		  order by b.order;
	quit;

	/*Groups to display*/
	%global includegroup;
	proc sql noprint;
		select compress(group) into: includegroup separated by ' '
		from _grouporder ;
	quit;

	%global cdfgrouplabel;
	proc sql noprint;		
		 select grouplabel into: cdfgrouplabel separated by '|'
		 from &groupfile.
		 where combinegrouplabel in (select group as combinegrouplabel from _grouporder);
	quit;


	/*Labels for censoring criteria*/
	%if %isBlank(&cens_elig) > 0 %then %let cens_elig =Disenrollment;
	%if %isBlank(&cens_dth) > 0 %then %let cens_dth =Evidence of Death;
	%if %isBlank(&cens_dpend) > 0 %then %let cens_dpend =End of Data Partner Data;
	%if %isBlank(&cens_qryend) > 0 %then %let cens_qryend =End of Query Period;
	%if %isBlank(&cens_episend) > 0 %then %let cens_episend =End of Exposure Episode;
	%if %isBlank(&cens_spec) > 0 %then %let cens_spec =Occurence of request-defined censoring criteria;
	%if %isBlank(&cens_event) > 0 %then %let cens_event =Occurence of Event;

	%global groupcnt displaycnt allcnt;
	%let groupcnt = %sysfunc(countw(&includegroup., " ")); /*Number of groups to include*/
	%let displaycnt = %sysfunc(countw(&censoring_display.)); /*Number of censoring criteria to include*/
	/*Will compute CDF for all censoring criteria, but only display those specified*/
	%let allcnt = %sysfunc(countw(&all_censor_criteria.)); /*Count of all censoring criteria*/

	/*Prepare group names for where in() statement*/
	%do a = 1 %to &groupcnt.;
		%let group = %upcase(%scan(&includegroup., &a., %str(" ")));
		%put &group.;
		%put &a.;
		%if &a = 1 %then %do;
			%let wheregroup = "&group";
		%end;
		%else %do;
			%let wheregroup = &wheregroup. , "&group";
		%end;
	%end;

	%macro buildvarlist();
		%global cens_cum_list censor_sumlist censor_cdflist KM_code km_varlist grouplabel_statement;

		%let cens_cum_list=;
		%let censor_sumlist=;
		%let censor_cdflist=;

		%let cdf_series_statement=;
		%let KM_code=;
		%let km_varlist=;
		%let km_series_statement=;
		%let grouplabel_statement=;

		%do i =1 %to &allcnt.;
			%let cens_cum_list = &cens_cum_list. %sysfunc(cats(cum_,%quote(%scan(&all_censor_criteria., &i.))));
			%let censor_sumlist = &censor_sumlist. %sysfunc(cats(sum_,%quote(%scan(&all_censor_criteria., &i.))));
			%let censor_cdflist = &censor_cdflist. %sysfunc(cats(cdf_,%quote(%scan(&all_censor_criteria., &i.))));
		%end;

		/*Dynamically build if/then statements for KM plot groups*/
		%do grps = 1 %to &groupcnt.;
		%let group= %upcase(%scan(&includegroup., &grps.));
		%let grouplabel = %scan(%bquote(&allgrouplabel.), &grps., %str(|)); 
			%let KM_code = &KM_code 
				if upcase(group) = "&group."
					%str(then do;)
						km_%scan(&includegroup., &grps.) %str(= km_estimate;)
						km_%scan(&includegroup., &grps.)_all %str(= km_allepisodes;
					end;
					else do;)
					km_%scan(&includegroup., &grps.) %str(= .;)
					km_%scan(&includegroup., &grps.)_all %str(= .;
					end;)
				;

			%let km_varlist = &km_varlist. %sysfunc(cats(km_,%quote(%scan(&includegroup., &grps.)))) %sysfunc(cats(km_,%quote(%scan(&includegroup., &grps.))_all));

		/*Code to assign display group names to group_label variable*/
				%let grouplabel_statement = %str(&grouplabel_statement. if upcase%(group%) = "&group." then group_label = "&grouplabel";);
		%end;
	%mend;
	%buildvarlist();

/*--------------------------------------------------------------------------------------------*/
/* 3: Generate data for CDF and KM plots													  */
/*--------------------------------------------------------------------------------------------*/

	/*Collapse across DPs and event_flag*/
	proc means data=agg_cida_censor nway noprint;
		var episodes &all_censor_criteria.;
		class group censdays_value;
		output out=agg_cida_censor_cum(drop=_:) sum=;
	run;

	proc sort data=agg_cida_censor_cum;
		by group censdays_value;
	run;

	/*Calculate total number of episodes for each censoring criteria (cens_cum_list)*/ 
	data cumulative_totals(keep=group &cens_cum_list. cum_episodes);
		
		array cens_cum_list{*} &cens_cum_list. cum_episodes;
		array censor {*} &all_censor_criteria. episodes;

		do i = 1 to dim(cens_cum_list);
			cens_cum_list{i} = 0;
		end;

		do until(last.group);
			set agg_cida_censor_cum;  
			by group;

			do a = 1 to dim(cens_cum_list);
				cens_cum_list{a} = cens_cum_list{a} + censor{a};
			end;
		end;
	run;

	/*Add in 0 censdays_value */
	data agg_cida_censor_cum;
		set agg_cida_censor_cum;
		by group;

		if first.group then do;
			output;
			array censor {*} &all_censor_criteria. episodes;
				do i = 1 to dim(censor);
					censor{i} = 0;
				end;

			censdays_value = 0;
			output;
		end;
		else do;
			output;
		end;
		drop i;
	run;

	proc sort data=agg_cida_censor_cum;
		by group censdays_value;
	run;

	/*Calculate CDF function, using total number of episodes and running sum*/
	/*Calculate KM curve*/
	data calculate_cumulatives;
		length group_label $30.;
		set agg_cida_censor_cum; 
		by group censdays_value;

		array censor_sum{*} &censor_sumlist. sum_episodes;
		array censor{*} &all_censor_criteria. episodes;
		array cens_cum_list{*} &cens_cum_list.; 
		array censor_cdflist{*} &censor_cdflist. ;

		if first.group then do;
			merge cumulative_totals;
			by group;
	
			do i = 1 to dim(censor);
				censor_sum{i} = censor{i};
			end;
		end;
		else do;
			do i = 1 to dim(censor);
				censor_sum{i} = censor{i} + censor_sum{i} ;
			end;
		end;

		retain &censor_sumlist. sum_episodes;

		/*------CDF plot is a 1-CDF plot-----*/
		do a = 1 to dim(censor_cdflist);
			if cens_cum_list{a} = 0 then censor_cdflist{a} = 1; else censor_cdflist{a} = 1-(censor_sum{a} / cens_cum_list{a});
		end;
		drop a i;

		/*-----KM Plot--------------------*/
		episodes_left = cum_episodes - sum_episodes;
		lag_episodes_left = lag(episodes_left);

		if first.group then do;
			lag_episodes_left = .; 
			km_estimate = 1;
			km_allepisodes = 1;
		end;
		else do;
			%if %eval(&type.=2) %then %do;
			if cens_event > 0 then do;
				km_estimate = km_estimate*(1-(cens_event/lag_episodes_left));
			end;
			else do;
				km_estimate = km_estimate;
			end;
			%end;

			if episodes > 0 then do;
				km_allepisodes = km_allepisodes*(1-(episodes/lag_episodes_left));
			end;
			else do;
				km_allepisodes = km_allepisodes;
			end;
		end;
		retain km_estimate km_allepisodes;

		/*Separate km_estimate into separate variables*/
		&km_code.;

		/*Create group_label variable. This will be used to name group in graphs*/;
		%put group_label ===> &grouplabel_statement.;
		if group_label = '' then group_label = group;

		/*Assign label to censoring reason for use in graphs and table*/
		%do lbl = 1 %to &displaycnt.;
			%let label = %scan(&censoring_display., &lbl.);
			label %sysfunc(cats(cdf_,%quote(%scan(&censoring_display., &lbl.)))) = "&&&label."; /*for CDF*/
		%end;
	run;

	/*Collapse for KM curve*/
	proc means data=calculate_cumulatives noprint nway;
		var &km_varlist.;
		class censdays_value;
		output out=km_data(drop=_:) max = ;
	run;

/*--------------------------------------------------------------------------------------------*/
/* 4: Table of Contents																	      */
/*--------------------------------------------------------------------------------------------*/
	/*For table of contents*/
	%let tablecount = 1;
	%let tableletter = a;
	%do grps = 1 %to &groupcnt.; /*Loop through groups - 1 plot per group*/
		%let group= %upcase(%scan(&includegroup., &grps.));
		%let grouplabel = %scan(%bquote(&cdfgrouplabel.), &grps., %str(|)); 	
		%put &group.;

		%tableletter();
		data toccdf;
			length tables $10 caption $500;
			tables = "Figure 1&tableletter.";

			 %if %symexist(CDF_title1) & %isBlank(&CDF_title1.) = 0 %then
				%let ctitle1 = &CDF_title1. &grouplabel.;
			 %else %let ctitle1 = Time to Censor &grouplabel.;
 
			 caption = "&ctitle1.";
		run;
		proc append data = toccdf base = tocdfall;
		run;
	%end;
	%let tablecount = 1;
	%let tableletter = a;
	%tableletter();

	%if %eval(&type.=2) %then %do;
	/*title for time to Event*/
	data tockmall;
		length tables $10 caption $500;
		tables = "Figure &tablecount.";
		
		%if %symexist(km_title1) & %isBlank(&km_title1.) = 0 %then 
			%let ktitle1 = &km_title1.;
		%else %let ktitle1 = Time to Event;
		%if %symexist(km_title2) & %isBlank(&km_title2.) = 0 %then
			%let ktitle2 = &km_title2.;
		%else %let ktitle2 =;

		caption = "&ktitle1. &ktitle2";
	run;
	/*Title for KM plot for all censoring (censor treated as event)*/
	%tableletter();
	%end;
	%else %do;
		data tockmall;
			length tables $10 caption $500;
			tables = '' ;
			caption = '';
			stop;
		run;
	%end;

	data toccdfall;
		length tables $10 caption $500;
		tables = "Figure &tablecount.";
		caption = "Time to Censor";
	run;

	%exit:

	%put =====> END MACRO: ms_t1t2_createcdf v1.3;

%mend ms_t1t2_createcdf;
