****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_t1t2_outputfigures.sas  
*
* Created (mm/dd/yyyy): 12/27/2017
* Last modified: 12/26/18
* Version: 1.2
*
*--------------------------------------------------------------------------------------------------
* PURPOSE: The macro produces CDF/KM figures
*                                        
*  Program inputs:                                                                                   
*
*  Program inputs:                                                                                   
* 
*  Program outputs:                                                                                                                                       
*  	- 
* 
*  PARAMETERS:                                                                       
*            
*  Programming Notes:                                                                                
*                                                                           
*
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*	1.1		  07/18/18	 AP			Change &grp to &grps (DEV-1033)
*
*	1.2		  12/26/18	 AP			Changed macro name from ms_outputfigures to ms_t1t2_outputfigures
*
***************************************************************************************************;

%macro ms_t1t2_outputfigures();

	%put =====> MACRO CALLED: ms_outputfigures v1.2;

	/*Display N*/
	%if %isBlank(&displayn) > 0 %then %let displayn =Y;

	/*Y Axis*/
	%if %isBlank(&cdf_ymin) > 0 %then %let cdf_ymin =0;
	%if %isBlank(&cdf_ymax) > 0 %then %let cdf_ymax =1;
	%if %isBlank(&cdf_ytick) > 0 %then %let cdf_ytick =.2;

	%if %isBlank(&km_ymin) > 0 %then %let km_ymin =0;
	%if %isBlank(&km_ymax) > 0 %then %let km_ymax =1;
	%if %isBlank(&km_ytick) > 0 %then %let km_ytick =.2;

	%if %isBlank(&km_ep_ymin) > 0 %then %let km_ep_ymin =0;
	%if %isBlank(&km_ep_ymax) > 0 %then %let km_ep_ymax =1;
	%if %isBlank(&km_ep_ytick) > 0 %then %let km_ep_ytick =.2;

	/*Default color list*/
	%let colorlist = DarkBlue Green Purple Red Orange Black Brown Magenta Yellow Skyblue Chartreuse Pink Maroon Grey;
 
	ods graphics on;

	%let tablecount = 1;
	%let tableletter = a;

	%do grps = 1 %to &groupcnt.; /*Loop through groups - 1 plot per group*/
		%let group= %upcase(%scan(&includegroup., &grps.));
		%let grouplabel = %scan(%bquote(&cdfgrouplabel.), &grps., %str(|)); 

		%tableletter();	
		ods proclabel = "Figure 1&tableletter.";

		/*CDF plot*/
		%if %symexist(CDF_title1) %then %do; 
			%if %isBlank(&CDF_title1.) = 0 %then %do; 
				title1 "&CDF_title1.";
			%end;
			%else %do; 
				title1 "Figure 1&tableletter.. Time to Censor"; 	
			%end;
		%end;
		%else %do;
			title1 "Figure 1&tableletter.. Time to Censor"; 
		%end;

		title2 "&grouplabel."; 
		
		%if %symexist(CDF_footnote1) %then %do; 
			%if %isBlank(&CDF_footnote1.) = 0 %then %do; 
				footnote1 "&CDF_footnote1.";
			%end;
			%else %do; footnote1 'A single episode may contribute to multiple categories if a patient was censored due to multiple criteria on the same day'; %end;
		%end;
		%else %do;
			footnote1 'A single episode may contribute to multiple categories if a patient was censored due to multiple criteria on the same day';
		%end;

		%if %symexist(CDF_footnote2) %then %do; 
			%if %isBlank(&CDF_footnote2.) = 0 %then %do; 
				footnote2 "&CDF_footnote2.";
			%end;
			%else %do; footnote2 ; %end;
		%end;
		%else %do;
			footnote2;
		%end;		

		/*Create inset statement. Looping through each censoring category, selecting max(cum_) into macro var*/
		%let inset_statement = ;
		%do c=1 %to &displaycnt.;
			%let censor = %scan(&censoring_display., &c.);
		
			proc sql noprint;
				select max(%sysfunc(cats(cum_,%quote(&censor.)))) into: n_value
				from calculate_cumulatives
				where upcase(group) = "&group.";
			quit;
			%let inset_statement = &inset_statement. "&&&censor. (n) = %trim(&n_value)";
		%end;
	
		proc sgplot data = calculate_cumulatives;
			%do i =1 %to &displaycnt.;
				/*Output 1 step statement per &censoring_display. variable*/
				step x= censdays_value y=%sysfunc(cats(cdf_,%quote(%scan(&censoring_display., &i.)))) / lineattrs=(thickness=2 pattern=solid color=%scan(&colorlist., &i.));
			%end;
			xaxis label = 'Days to Censor' 
			%if %isBlank(&cdf_xmin.) = 0 %then %do; values = (&cdf_xmin. to &cdf_xmax. by &cdf_xtick.); %end; ;
				yaxis label = '1- CDF' 
			%if %isBlank(&cdf_ymin.) = 0 %then %do; values = (&cdf_ymin. to &cdf_ymax. by &cdf_ytick.); %end; ;
			%if %upcase(&displayn.) = Y %then %do; inset &inset_statement. / position=topright; %end;
			where upcase(group) = "&group.";
		run;
	%end;

	/*KM Curve*/
	%let tablecount = 1;
	%let tableletter = a;

	%if %eval(&type.=2) %then %do;

		%tableletter();

		title1 "Figure &TableCount.. Time to Event";
		title2 ;
		footnote1 ;
		footnote2 ;

		%if %symexist(km_title1) %then %do; 
			%if %isBlank(&km_title1.) = 0 %then %do; 
				title1 "&km_title1.";
			%end;
		%end;

		%if %symexist(km_title2) %then %do; 
			%if %isBlank(&km_title2.) = 0 %then %do; 
				title2 "&km_title2.";
			%end;
		%end;

		%if %symexist(km_footnote1) %then %do; 
			%if %isBlank(&km_footnote1.) = 0 %then %do; 
				footnote1 "&km_footnote1.";
			%end;
		%end;

		%if %symexist(km_footnote2) %then %do; 
			%if %isBlank(&km_footnote2.) = 0 %then %do; 
				footnote2 "&km_footnote2.";
			%end;
		%end;
					

		/*Create inset statement. Looping through each group selecting max(cum_cens_event) into macro var*/
		%let inset_statement = ;
			%do d=1 %to &groupcnt.;
				%let group = %scan(&includegroup., &d.);	
				%let grouplabel = %scan(%bquote(&cdfgrouplabel.), &d., %str(|));	
				proc sql noprint;
					select max(cum_cens_event) into: n_value
					from calculate_cumulatives
					where upcase(group) = %upcase("&group.");
				quit;
				%let inset_statement = &inset_statement. "&grouplabel. (n) = %trim(&n_value)";
			%end;


		*** SGPLOT *** ;

		ods proclabel = "Figure &TableCount.";

		proc sgplot data=km_data;
			/*Output 1 step statement per &includegroup. variable AND add group label to legend for KM graph*/
			%do grps = 1 %to &groupcnt.;
				%let labelvar = %scan(%bquote(&cdfgrouplabel.), &grps., %str(|));		
				%put labelvar ====> &labelvar.;	

					%if %symexist(labelvar) = 1 %then %do;
						%if %isblank(%bquote(&labelvar.)) = 0 %then %do;
							%let label_statment = legendlabel="&labelvar.";
							step x= censdays_value y=%sysfunc(cats(km_,%quote(%scan(&includegroup., &grps.)))) / 
								&label_statment. lineattrs=(thickness=2 pattern=solid color=%scan(&colorlist., &grps.));
						%end;
						%else %do;
							step x= censdays_value y=%sysfunc(cats(km_,%quote(%scan(&includegroup., &grps.)))) / lineattrs=(thickness=2 pattern=solid color=%scan(&colorlist., &grps.));
						%end;
					%end;
					%else %do;
						step x= censdays_value y=%sysfunc(cats(km_,%quote(%scan(&includegroup., &grps.))))/ lineattrs=(thickness=2 pattern=solid color=%scan(&colorlist., &grps.));
					%end;
			%end;

			xaxis label = 'Days' %if %isBlank(&km_xmin.) = 0 %then %do; values = (&km_xmin. to &km_xmax. by &km_xtick.); %end; ;
			yaxis label = 'Survival Probability' %if %isBlank(&km_ymin.) = 0 %then %do; values = (&km_ymin. to &km_ymax. by &km_ytick.); %end; ;
			%if %upcase(&displayn.) = Y %then %do; inset &inset_statement.; %end;
		run;
	%end;

	/*KM Plot for all censoring (censor treated as event)*/
	%tableletter();

	ods proclabel = "Figure &TableCount.";

	title1 "Figure &tablecount.. Time to Censor";
	title2;
	footnote1;
	footnote2;
			
	proc sgplot data=km_data;
		/*Output 1 step statement per &includegroup. variable AND add group label to legend for KM graph*/
		%do grps = 1 %to &groupcnt.;
			%let group= %upcase(%scan(&includegroup., &grps.));
				%let labelvar = %scan(%bquote(&cdfgrouplabel.), &grps., %str(|));	
				%if %symexist(labelvar) = 1 %then %do;
					%if %isblank(%bquote(&labelvar.)) = 0 %then %do;
						%let label_statment = legendlabel="&labelvar.";
							step x= censdays_value y=%sysfunc(cats(km_,%quote(%scan(&includegroup., &grps.))_all)) / 
							&label_statment. lineattrs=(thickness=2 pattern=solid color=%scan(&colorlist., &grps.));
						%end;
					%else %do;
						step x= censdays_value y=%sysfunc(cats(km_,%quote(%scan(&includegroup., &grps.)),_all)) / lineattrs=(thickness=2 pattern=solid color=%scan(&colorlist., &grps.));
					%end;
				%end;
				%else %do;
					step x= censdays_value y=%sysfunc(cats(km_,%quote(%scan(&includegroup., &grps.)),_all))/ lineattrs=(thickness=2 pattern=solid color=%scan(&colorlist., &grps.));
				%end;
		%end;

		xaxis label = 'Days' %if %isBlank(&km_ep_xmin.) = 0 %then %do; values = (&km_ep_xmin. to &km_ep_xmax. by &km_ep_xtick.); %end; ;
		yaxis label = 'Survival Probability' %if %isBlank(&km_ep_ymin.) = 0 %then %do; values = (&km_ep_ymin. to &km_ep_ymax. by &km_ep_ytick.); %end; ;
	run;

	ods graphics off;

	%put =====> END MACRO: ms_t1t2_outputfigures v1.2;

%mend ms_t1t2_outputfigures;
