****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: runCIDA.sas  
*
* Created (mm/dd/yyyy): 01/26/2016
* Last modified: 
* Version: 7.3.0
*
*--------------------------------------------------------------------------------------------------
* PURPOSE:
*   Macro to run CIDA and Analytic Code if necessary.                                        
*   
*  Program inputs:                                                                                   
*                                     
*  Program outputs:                                                                                                                                       
*                                                                                                  
*  PARAMETERS:    
*		All the parameters are set by the run_programs program. 
*            
*  Programming Notes:                                                                                
*
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*             mm/dd/yy
*
***************************************************************************************************;
/* Macro to run CIDA and Analytic Code if necessary */

%macro runCIDA ;

  %LET RUNID=%LOWCASE(&RUNID.);

  proc printto log="&MSOC.&RUNID._cida.log" new;
  run;

  %put =====> MACRO CALLED: runCIDA v7.3.0;

  %let Ver=7.3.0;  

  /*option required to ensure successful multiple runs of CIDA*/
  options nosyntaxcheck;

  *Clean work library;
  proc datasets lib=work nolist kill; quit; run;

  *Clean dplocal library of temporary datasets;
  proc datasets lib=dplocal nolist nowarn;
	delete _: death: drug: med: mil: enr: elix: pre: lab:;
  quit;

  /**********/
  /** CIDA **/
  /**********/
  %ms_cidanum(RUNID=&RUNID.,
              PROJID=&PROJID.,  
              WPTYPE=&WPTYPE.,
              WPID=&WPID.,
			  DPID=&DPID.,
              VERID=&VERID.,
              PERIODIDSTART=&PERIODIDSTART.,
              PERIODIDEND=&PERIODIDEND.,
              ANALYSIS=&ANALYSIS.,
              MONITORINGFILE=&MONITORINGFILE.,
			  USERSTRATA=&USERSTRATA.,
              COMBOFILE=&COMBOFILE.,
              COHORTFILE=&COHORTFILE.,
              COHORTCODES=&COHORTCODES.,
              INCLUSIONCODES=&INCLUSIONCODES.,
              STOCKPILINGFILE=&STOCKPILINGFILE.,
			  RUN_ENVELOPE=&RUN_ENVELOPE.,
              FREEZEDATA=&FREEZEDATA.,
			  ZIPFILE=&ZIPFILE.,
              LABSCODEMAP=&LABSCODEMAP.,
			  SURVEILLANCEMODE=&SURVEILLANCEMODE.,
			  DISTINDEX=&DISTINDEX.,
              TYPE1FILE=&TYPE1FILE.,
              TYPE2FILE=&TYPE2FILE.,
              TYPE3FILE=&TYPE3FILE.,
			  T3METADATA=&T3METADATA.,
			  TYPE4FILE=&TYPE4FILE.,
			  PREGDUR=&PREGDUR.,			  
			  TYPE5FILE=&TYPE5FILE.,
			  TYPE6FILE=&TYPE6FILE.,
              COVARIATECODES=&COVARIATECODES.,
              UTILFILE=&UTILFILE.,
              COMORBFILE=&COMORBFILE.,
              DRUGCLASSFILE=&DRUGCLASSFILE.,
			  PROFILE=&PROFILE.,
			  MFUFILE=&MFUFILE.,
			  MULTEVENTFILE=&MULTEVENTFILE.,
			  MULTEVENTFILE_ADHERE=&MULTEVENTFILE_ADHERE.,
			  CONCFILE=&CONCFILE.,
			  OVERLAPFILE=&OVERLAPFILE.,
			  OVERLAPFILE_ADHERE=&OVERLAPFILE_ADHERE.,
			  ITSFILE=&ITSFILE.,
			  TREATMENTPATHWAYS=&TREATMENTPATHWAYS.,
			  MICOHORTFILE=&MICOHORTFILE.
              );  

  /**************/
  /** PSA Tool **/
  /**************/

  %if (%UPCASE("&ANALYSIS.") eq "PS") | (%UPCASE("&ANALYSIS.") eq "MS") %then %do ; 

    %MS_COVARIATEADJUSTMENT(PERIODSTART=&PERIODIDSTART.,
                         	PERIODEND=&PERIODIDEND.,
							ANALYSIS=&ANALYSIS.,
                         	COVARIATECONDITION=&COVARIATECODES. ,
                         	COVARIATES_CONSIDERED=&COVARIATES_CONSIDERED.,
                         	COVARIATES_SELECTED=&COVARIATES_SELECTED.,
                         	RANKING=&RANKING.,
                         	ZERO_CELL_CORR=&ZERO_CELL_CORR.,
                         	HDVARSEL_INPUT=&RUNID._claims_ICDDX09 &RUNID._claims_ICDDX10 &RUNID._claims_DRUGCLASS &RUNID._claims_CPT &RUNID._claims_ICDPX09 &RUNID._claims_ICDPX10 &RUNID._claims_HCPCS,                         	
                         	COMPARE_INPUT=&COMPARISON. ,
							MFM_INPUT=&MFMFILE.,
						 	ANALYTICSUBGROUPS=&ANALYTICSUBGROUPS.,
                         	INDLEVEL=&INDLEVEL.,
                            PERCENTILES=&PERCENTILES.,
                            UNCONDITIONAL=&UNCONDITIONAL.,
                            DIAGNOSTICS=&DIAGNOSTICS.
                         	) ;
  %end ;

  %put NOTE: ******** END OF MACRO: runCIDA v7.3.0 ********;

  *Clear work;
  proc datasets nowarn noprint lib=work kill;
  quit;

  proc printto;
  run;

%mend runCIDA ;

%runCIDA ;
