****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_finalizemoiepisodes.sas  
*
* Created (mm/dd/yyyy): 04/17/2018
* Last modified: 05/31/2018
* Version: 1.1
*
*--------------------------------------------------------------------------------------------------
* PURPOSE: Restrict MOI episodes and dispensings to only those during a valid pregnancy/control episode
*   
*  Program inputs:                                                                                   
* 
*  Program outputs:                                                                                                                                       
* 
*  PARAMETERS:                                                                       
*
*  Programming Notes:                                                                                
*                                                                           
*
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
* 	1.1		  05/31/18	 AP			Turned off control group if requested
*
***************************************************************************************************;

%macro ms_finalizemoiepisodes();

	%put =====> MACRO CALLED: ms_finalizemoiepisodes v1.1;

	* Keep only the secondary cohort episodes of members who are in the primary cohort (to avoid unnecessary big file);
	proc sql noprint;
		create table _UniquePtsList as
		select distinct(PatId) from _PtsMasterList
		%if "&t4_nopreggroup." = "Y" %then %do;
		union
		select distinct(PatId) from _ControlGroup
		%end; 
		;
	quit;		

	data _tmp_PtsMasterList2;
		merge _UniquePtsList(in=a)
			  _PtsMasterList2 (in=b);
		by Patid;
		if a and b;
	run;

	*Save File of all dispensings during secondary cohort episodes;
	%do n=1 %to &NUM_MPN.;
		proc sort nodup data=_tmp_PtsMasterList2(where=(MOINAME="MP&n")) out=_ptsmasterlist2mp&n.;
			by patid indexdt;
		run;

		%ms_shaveoutside(reffile=_ptsmasterlist2mp&n.,
		                 refstart=IndexDt,
		                 refend=EpisodeEndDt,
		                 KeepPartBf=N,
		                 ToShaveFile=_GroupIndex&n.,
		                 ToShaveStart=Adate,
		                 ToShaveEnd=ExpireDt,
		                 outfile=_GroupUtilFile_moi&n.);

		*Calculate Dispensing metrics for each MOI episode;
		proc means data=_GroupUtilFile_moi&n. nway noprint;
			var NumDispensing;
		    class PatId IndexDt;
		    output out=_summarizedutil_&n.(rename=_freq_=AdjustedDisp drop=_Type_) sum(NumDispensing)= RawDisp;
		run;	

    	data _PtsMasterList2_&n.;
	    	merge _ptsmasterlist2mp&n.(in=a)
	    	      _summarizedutil_&n. (in=b);
			by PatId IndexDt;
    		if a or b;*defensive;
    	run;

		%if %eval(&n=1) %then %do;
			data _PtsMasterList2;
				set _PtsMasterList2_&n.;
			run;

			data _GroupUtilFile;
				set _GroupUtilFile_moi&n.;
				format MOINAME $10.;
				MOIName = "MP&n";
			run;
		%end;
		%else %do;
			data _PtsMasterList2;
				set _PtsMasterList2 _PtsMasterList2_&n.;
			run;

			data _GroupUtilFile;
				set _GroupUtilFile
					_GroupUtilFile_moi&n.(in=b);
					if b then do;
						format MOINAME $10.;
						MOIName = "MP&n";
					end;
			run;
		%end;

		proc datasets nowarn noprint lib=work;	
			delete _summarizedutil_&n. _GroupUtilFile_moi&n.;
		quit;

	%end; /*loop through MOI*/

	%put NOTE: ******** END OF MACRO: ms_finalizemoiepisodes v1.1 ********;

%mend ms_finalizemoiepisodes;
