****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_t1t2_outputt1t2table.sas  
*
* Created (mm/dd/yyyy): 12/27/2017
* Last modified: 12/15/2018
* Version: 1.3
*
*--------------------------------------------------------------------------------------------------
* PURPOSE: This macro produces a proc report statement to print summary tables
*                                        
*  Program inputs:        
*	-data: dataset name
*	-varlist: list of variables to include in report
*	-title: Table title
* 	-var: List of variables to stratify
*	-sheetname: Label for procedure in PDF sidebar/Excel tab
*
*  Program inputs:                                                                                   
* 
*  Program outputs:                                                                                                                                       
*  	- 
* 
*  PARAMETERS:                                                                       
*            
*  Programming Notes:                                                                                
*                                                                           
*
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*   1.1		  04/05/18	 AP			Removed arial font (QRP-571)
*									Added additional denominator footnotes (QRP-560)
*
*   1.2		  07/15/18	 AP			Added covariate stratification
*
*   1.3		  12/15/18	 AP			Added font back in as arial
*									Changed macro name from ms_outputt1t2table to ms_t1t2_outputt1t2table
*
***************************************************************************************************;

%macro ms_t1t2_outputt1t2table(data=, varlist=, title=, var=, sheetname=);

	%put =====> MACRO CALLED: ms_t1t2_outputt1t2table v1.3;

	options orientation = landscape;
	&report_header.;

	ods proclabel = "&sheetname.";

	 proc report data = &data. nofs nowd spanrows missing headskip split="*"
		style(header)=[rules=none background=white /*color = black*/font_weight=bold font_size=8pt just=l fontfamily=arial vjust=b bordertopcolor=black borderbottomcolor=black] split='*'
		style(report)=[rules=none frame=box fontfamily=arial cellpadding =&line_spacing.pt /*color = black just=l*/];
			
		columns ("&title." combinegrouplabel level &&var. &&varlist. header grouplabel newcategory);

		define header / order noprint order=data ' ';
		define grouplabel / order noprint order=data ' ';
		define newcategory / order noprint order=data ' ';
			
		%if "&&var." = "" %then %do;
		define level / id style=[backgroundcolor = white color = white];
		%end;
		%else %do;
		define level / noprint;
		%end;
			
		%do c = 1 %to %sysfunc(countw(&&var.));			
			%let cat = %scan(&&var., &c.);
			 %if %sysfunc(countw(&&var.)) = 1 or &c. = %sysfunc(countw(&&var.)) %then %do;
				define &cat. / id 
					style(column)=[font_size=8pt fontfamily=arial
						%if "%lowcase(&cat.)" = "race" or "%lowcase(&cat.)" = "hispanic" %then width= 2.3in;
																						 %else %if "%lowcase(&cat.)" = "agegroup" %then width = 1.1in;
																						 %else %if "%lowcase(&cat.)" = "hhs_reg" %then width = 1.35in;
																						 %else %if %index("%lowcase(&cat.)", covar) >0 %then width = 2in;
																			 			 %else width =.81in; just=l indent=20] 
						style(header)=[just=C background=white borderbottomcolor=black];
			%end;
			 %else %do;
			 	define &cat. / noprint;
			 %end;

		%end;
		%do v = 1 %to %sysfunc(countw(&&varlist.));
			%let varname = %lowcase(%scan(&&varlist., &v.));
				%if "&varname." = "adjustedcodecount" or "&varname." = "rawcodecount" 
					or "&varname." = "daysupp" or "&varname." = "amtsupp" or "&varname." = "tte" or  "&varname." = "dennumpts" 
					or "&varname." = "npts" or "&varname." = "episodes" or "&varname." = "eps_wevents" or "&varname." = "all_events" %then %do;

					define &varname. / display format=comma10.0
						 style(column)=[font_size=8pt fontfamily=arial width=.72in just=c] style(header)=[just=C background=white borderbottomcolor=black];
				%end;	
				%else %do;
					define &varname. / display format=comma13.2
							style(column)=[font_size=8pt fontfamily=arial width=.72in just=c] style(header)=[just=C background=white borderbottomcolor=black];
				%end;
				%if  "&varname." = "dennummemdays" %then %do;
					define &varname. / display format=comma14.0
							 style(column)=[font_size=8pt fontfamily=arial width=.9in just=c] style(header)=[just=C background=white borderbottomcolor=black];
				%end;	
				%if  "&varname." = "dennummemdaysdiv36525" or "&varname." = "ttediv36525" %then %do;
					define &varname. / display format=comma13.1 center 
							 style(column)=[font_size=8pt fontfamily=arial width=.82in just=c] style(header)=[just=C width=.82in background=white borderbottomcolor=black];
				%end;		
		%end;

		define combinegrouplabel / noprint;

		/*add header line*/
		%if %length(&header.) > 0 %then %do; 
			compute before header / style=[backgroundcolor=darkgray font_size=8pt fontfamily=arial just=L font_weight=bold bordertopcolor=black borderbottomcolor=black];
			length text $100;
				text = header;
				num = 100;
				line text $varying. num;
			endcomp;
		%end;
		
		/*add grouplabel*/
		compute before grouplabel / style=[backgroundcolor=white fontfamily=arial fontstyle=italic font_size=8pt just=L font_weight = medium bordertopcolor=black ];
			length text $100;
			text = grouplabel;
			num = 100;
			line text $varying. num;	
		endcomp;
			
		%if %sysfunc(countw(&&var.)) ge 2 %then %do;
		/*add grouplabel*/
		compute before newcategory / style=[backgroundcolor=white fontfamily=arial fontstyle=italic font_size=8pt just=L font_weight = medium bordertopcolor=black ];
			length text $100;
			text = newcategory;
			num = 100;
			line text $varying. num;	
		endcomp;
		%end;

		/*footnote in table*/
		%if %index(%lowcase(&&varlist.),dennumpts) > 0 | %index(%lowcase(&&varlist.),dennummemdays) > 0 | %index(%lowcase(&&varlist.),dennummemdaysdiv36525) > 0
			| %index(%lowcase(&&varlist.),eps_weventsdivdennumpts) > 0 | %index(%lowcase(&&varlist.),nptsdivdennumpts) > 0 %then %do;
		compute after / style=[just=L fontfamily=arial font_size=8pt bordertopcolor=black];
			line '';

			*eligible members only;
			%if (%sysfunc(indexw(%lowcase(&&varlist.),dennumpts) ) > 0 | %sysfunc(indexw(%lowcase(&&varlist.),eps_weventsdivdennumpts) ) > 0 | %sysfunc(indexw(%lowcase(&&varlist.),nptsdivdennumpts) ) > 0 )
			& %sysfunc(indexw(%lowcase(&&varlist.),dennummemdays) ) = 0 & %sysfunc(indexw(%lowcase(&&varlist.),dennummemdaysdiv36525) ) = 0 %then %do;
			line "^{super 1}Eligible Members are reflective of the number of patients that met all cohort entry criteria on at least one day during the query period";
			%end;

			*eligible member days only;
			%if %sysfunc(indexw(%lowcase(&&varlist.),dennummemdays) ) > 0 & %sysfunc(indexw(%lowcase(&&varlist.),dennumpts) ) = 0 & %sysfunc(indexw(%lowcase(&&varlist.),dennummemdaysdiv36525) ) = 0
			& %sysfunc(indexw(%lowcase(&&varlist.),eps_weventsdivdennumpts) ) = 0 & %sysfunc(indexw(%lowcase(&&varlist.),nptsdivdennumpts) ) = 0 %then %do;
			line "^{super 1}Eligible Member-Days are reflective of the number of patients that met all cohort entry criteria on at least one day during the query period";
			%end;

			*eligible member years only;
			%if %sysfunc(indexw(%lowcase(&&varlist.),dennumpts) ) = 0 & %sysfunc(indexw(%lowcase(&&varlist.),dennummemdays) ) = 0 & %sysfunc(indexw(%lowcase(&&varlist.),dennummemdaysdiv36525) ) > 0
			& %sysfunc(indexw(%lowcase(&&varlist.),eps_weventsdivdennumpts) ) = 0 & %sysfunc(indexw(%lowcase(&&varlist.),nptsdivdennumpts) ) = 0 %then %do;
			line "^{super 1}Eligible Member-Years are reflective of the number of patients that met all cohort entry criteria on at least one day during the query period";
			%end;

			*eligible member days and years;
			%if (%sysfunc(indexw(%lowcase(&&varlist.),dennummemdays)) > 0 & %sysfunc(indexw(%lowcase(&&varlist.),dennummemdaysdiv36525) ) > 0) 
				& %sysfunc(indexw(%lowcase(&&varlist.),dennumpts)) = 0 & %sysfunc(indexw(%lowcase(&&varlist.),eps_weventsdivdennumpts)) =0 & %sysfunc(indexw(%lowcase(&&varlist.),nptsdivdennumpts)) = 0 %then %do;
			line "^{super 1}Eligible Member-Days and Member-Years are reflective of the number of patients that met all cohort entry criteria on at least one day during the query period";
			%end;

			*eligible members and years;
			%if (%sysfunc(indexw(%lowcase(&&varlist.),dennumpts) ) > 0 | %sysfunc(indexw(%lowcase(&&varlist.),eps_weventsdivdennumpts) ) > 0 | %sysfunc(indexw(%lowcase(&&varlist.),nptsdivdennumpts) ) > 0)
			& (%sysfunc(indexw(%lowcase(&&varlist.),dennummemdaysdiv36525)) > 0) & (%sysfunc(indexw(%lowcase(&&varlist.),dennummemdays) ) = 0) %then %do;
			line "^{super 1}Eligible Members and Member-Years are reflective of the number of patients that met all cohort entry criteria on at least one day during the query period";
			%end;

			*eligible members and days;
			%if (%sysfunc(indexw(%lowcase(&&varlist.),dennumpts) ) > 0 | %sysfunc(indexw(%lowcase(&&varlist.),eps_weventsdivdennumpts) ) > 0 | %sysfunc(indexw(%lowcase(&&varlist.),nptsdivdennumpts) ) > 0) 
			& (%sysfunc(indexw(%lowcase(&&varlist.),dennummemdaysdiv36525) ) = 0) & (%sysfunc(indexw(%lowcase(&&varlist.),dennummemdays) ) > 0) %then %do;
			line "^{super 1}Eligible Members and Member-Days are reflective of the number of patients that met all cohort entry criteria on at least one day during the query period";
			%end;

			*eligible members, days, and years;
			%if (%sysfunc(indexw(%lowcase(&&varlist.),dennumpts) ) > 0 | %sysfunc(indexw(%lowcase(&&varlist.),eps_weventsdivdennumpts) ) > 0 | %sysfunc(indexw(%lowcase(&&varlist.),nptsdivdennumpts) ) > 0)
			& (%sysfunc(indexw(%lowcase(&&varlist.),dennummemdaysdiv36525) ) > 0) & (%sysfunc(indexw(%lowcase(&&varlist.),dennummemdays) ) > 0) %then %do;
			line "^{super 1}Eligible Members, Member-Days, and Member-Years are reflective of the number of patients that met all cohort entry criteria on at least one day during the query period";
			%end;
		endcomp;
		%end;
	run;

	%put =====> END MACRO: ms_t1t2_outputt1t2table v1.3;

%mend ms_t1t2_outputt1t2table;
