****************************************************************************************************
*                                           PROGRAM OVERVIEW
****************************************************************************************************
*
* PROGRAM: ms_t1t2table.sas  
*
* Created (mm/dd/yyyy): 12/26/2017
* Last modified: 02/12/2019
* Version: 1.3
*
*--------------------------------------------------------------------------------------------------
* PURPOSE: The macro produces Type 1 and Type 2 report
*                                        
*  Program inputs:                                                                                   
*  	- For Type 1 requests: [RUNID]_t1_cida.sas7bdat 
*
*  Program inputs:                                                                                   
*  	- For Type 2 requests: [RUNID]_t2_cida.sas7bdat 
* 
*  Program outputs:                                                                                                                                       
*  	- 
* 
*  PARAMETERS:                                                                       
*            
*  Programming Notes:                                                                                
*                                                                           
*
*
*--------------------------------------------------------------------------------------------------
* CONTACT INFO: 
*  Sentinel Coordinating Center
*  info@sentinelsystem.org
*
*--------------------------------------------------------------------------------------------------
*  CHANGE LOG: 
*
*   Version   Date       Initials      Comment (reference external documentation when available)
*   -------   --------   --------   ---------------------------------------------------------------
*	1.1		  04/16/18	   AP		Replaced Dispensings with AdjustedCodeCount/RawCodeCount
*
*	1.2		  07/16/18	   AP		Added covariate stratification, changed &grp to &grps (DEV-1033)
*
*	1.3 	  02/12/19	   AP		Changed DP macro variable to prevent conflict with CC defined var
*
***************************************************************************************************;

%macro ms_t1t2table();

	%put =====> MACRO CALLED: ms_t1t2table v1.3;

/************************************************************************************************************************************
*	1. Aggregate data from different runs within a Type						
************************************************************************************************************************************/	
	%if &type.= 1 or &type. = 2  %then %do;

		/*Aggregate data for groups in column group1*/
		%if %length(&T1GroupList.) > 0 %then %do;
			%do dps = 1 %to &num_dp;
				%do grps = 1 %to &NUM_T1Groups.;
					%let RUNID = %scan(&T1runids., &grps.);
					%let group = %scan(&T1GroupList,&grps.);

					%if %sysfunc(exist(msoc.&RUNID._t&type._cida))=0 %then %do;
						%put WARNING: t&type._cida does not exist. Please confirm correct analysis type is specfied. Program will abort;
						%abort; 
				   %end;
				   %else %do;		
						data group1_dp&dps._grp&grps.;
					 	   	length combinegrouplabel $61;
					 	  	set msoc.&RUNID._t&type._cida;
						  	where group in ("&group.") and level in (&level_to_stratify.);
							combinegrouplabel = GROUP;
					 	 run;		

						/*No two runids can have same group*/
					 	%if ("&dps." eq "1") and ("&grps" eq "1") %then %do;
					 		data agg_dps_group1;
								set group1_dp&dps._grp&grps.;
							run;	
					 	%end;
					 	%else %do;
					 	 	data agg_dps_group1;
						 		set agg_dps_group1
							 	group1_dp&dps._grp&grps.;
							run;
					 	%end;
					%end;
				%end; /*end of all runids within DP*/
			%end; /*end of all DPs*/;
	 	%end; /*if non-combination groups exist*/

		/*Aggregate data for combined groups*/
		%if %length(&combinegroup1.) > 0 and %length(&combinegroup2.) > 0 %then %do;
			%do dps = 1 %to &num_dp.;
				%let DPID = %scan(&random_dpid_list,&dps);

					%do r = 1 %to &NUM_Crunids.;
						%put combiner  resolves to ==> &r.;
						%do c = 1 %to 2;
							%put combiner  resolves to ==> &&combinerun&c..;
							%let RUNID&c. = %scan(&&combinerun&c.., &r.);
							%let GROUP&c. = %scan(&&combinegroup&c.., &r.);
						%end;
						%if %sysfunc(exist(msoc.&RUNID1._t&type._cida))=0 or %sysfunc(exist(msoc.&RUNID2._t&type._cida))=0 %then %do;
					    	%put WARNING: t&type._cida does not exist. Please confirm correct analysis type specified. Program will abort;
							%abort; 
			   			%end;
						%else %do;
							%do c = 1 %to 2;
								data combine&dps._&r._&c.;
									set msoc.&&RUNID&c.._t&type._cida;
									where group in ("&&GROUP&c..") and level in (&level_to_stratify.);
								 run;
							%end;		

							proc sql noprint;
								select combinedgroupname into: combinedgroupname
								from infolder.&groupfile.
								where group1 = "&group1." and group2 = "&group2.";
							quit;	
							
							 data combine&dps.;
							 	 length combinegrouplabel $61;
	  								set combine&dps._&r._1 combine&dps._&r._2; 
								 combinegrouplabel = "&combinedgroupname.";
							 run;

							 proc summary data = combine&dps. nway missing;
							 	 class combinegrouplabel level sex agegroup agegroupnum year month 
									  &zip3level. &statelevel. &racelevel. &hhslevel. &cblevel. &hispaniclevel. &zip_uncertain. &covarlist.;
								 var &origvars.;
							 output out = combine&dps. (drop = _:) sum=;
							 run;
							 %if ("&r." eq "1") and ("&dps" eq "1") %then %do;
							 	data agg_dps_combine;
									set combine&dps.;
								run;
				 			%end;
				 			%else %do;
				 	 			data agg_dps_combine;
					 	 			set agg_dps_combine
						 	 		combine&dps.;
					 			run;
				 			%end;	
						%end; /*end of processing data for each combined run*/
					%end; /*end of all combined groups within DP*/
				%end;	/*end of all DPS*/
			%end; /*end of process for combined groups*/
		%end; /*type1 or type2*/
		%else %do;
			%put WARNING: TYPE not specified or Invalid. Please enter 1 or 2 in type parameter. Program will abort.;
			%abort;
		%end;

		/*append datasets from group1 and combined groups*/
		data agg_dps_t&type. (drop = _sex );
		  set 
			%if %sysfunc(exist(agg_dps_group1)) %then %do;
				agg_dps_group1 
					(rename = (sex = _sex 
						%if "&racelevel." eq "race" %then race = _race;
						%if "&hispaniclevel." eq "hispanic" %then hispanic = _hispanic;
						%if "&hhslevel." eq "hhs_reg" %then hhs_reg = _hhs_reg;
						%if "&cblevel." eq "cb_reg" %then cb_reg = _cb_reg;))
			%end;
		  	%if %sysfunc(exist(agg_dps_combine)) %then %do;
				agg_dps_combine 
					(rename = (sex = _sex 
						%if "&racelevel." eq "race" %then race = _race;
						%if "&hispaniclevel." eq "hispanic" %then hispanic = _hispanic;
						%if "&hhslevel." eq "hhs_reg" %then hhs_reg = _hhs_reg;
						%if "&cblevel." eq "cb_reg" %then cb_reg = _cb_reg;))
			%end;
			;
			length sex $15 ;
			sex = put(_sex, $levelfmt.);
			%if "&racelevel." eq "race" %then %do;
			length race $45;
			race = put(_race, $levelfmt.);
			drop _race;
			%end;
			%if "&hispaniclevel." eq "hispanic" %then %do;
			length hispanic $20;
			hispanic = put(_hispanic, $levelfmt.);
			drop _hispanic;
			%end;
			%if "&hhslevel." eq "hhs_reg" %then %do;
			length hhs_reg $25;
			hhs_reg = put(_hhs_reg, $levelfmt.);
			drop _hhs_reg;
			%end;
			%if "&cblevel." eq "cb_reg" %then %do;
			length cb_reg $25;
			cb_reg = put(_cb_reg, $levelfmt.);
			drop _cb_reg;
			%end;
		run;
		
		/*if stratification by zip3 is requested, add in state as well*/
		%if "&zip3level." = "zip3" %then %do;
			%ms_t1t2_addstatetozip3(data = agg_dps_t&type.); 
		%end;

		/*Aggregate data across all DPs*/ 
		proc summary data = agg_dps_t&type. nway missing;
			class level combinegrouplabel agegroupnum sex  agegroup  year month &zip3level. &statelevel. &hhslevel. &cblevel. &racelevel. &hispaniclevel. &zip_uncertain. &covarlist.;;
			var &origvars.;
			output out = agg_dps_t&type._summ (drop = _:) sum=;
		run;
		

/************************************************************************************************************************************
*	2. Add calculated variables		
************************************************************************************************************************************/

	%if %sysfunc(exist(infolder.&columns_table.)) %then %do;

		data &columns_table.;
			format newvar $32.;
			 set infolder.&columns_table.;
			newvar = lowcase(tranwrd(compress(variable, "(),. * 1000 10000 100000"), "/", "div")); 
			variable = tranwrd(compress(variable, ",.()"), "/36525", "div36525");
		run;
		
		proc sql noprint;
			select compress(variable) into: customvars separated by ' ' 
			from &columns_table.;
	    	select  newvar into: newcustomvars separated by ' ' 
			from &columns_table.;
			select count(distinct(variable)) into: numcustomvars
			from &columns_table.;
		quit;

		%put ===> custom columns: &customvars.;
		%put ===> &newcustomvars.;

		/*Extracting different X factors*/
		data _null_;
		/*initialize macro variables*/
		%let factor1 =;
		%let factor2 =;
		%let factor3 =;
		%do var = 1 %to &numcustomvars.;
		 %let variable = %scan(&customvars., &var., %str(" "));
		 %let newvar = %scan(&newcustomvars., &var.);
		 	%if %index(&variable, *) %then %do;
				%let y = %sysfunc(substr(&variable., %index(&variable, *)+1));
					%if &y. = 1000 or &y. = 10000 or &y. = 100000 %then %do;
						factor = (&y./1000);
						%if %index(%lowcase(&variable), npts/dennumpts) %then %do;
						call symputx("factor1", strip(factor)||"K");
						%end;
						%if %index(%lowcase(&variable), eps_wevents/ttediv36525) %then %do;
						call symputx("factor2", strip(factor)||"K");
						%end;
						%if %index(%lowcase(&variable), eps_wevents/dennumpts*) %then %do;
						call symputx("factor3", strip(factor)||"K");
						%end;
					%end;
					%else %do;
					%put WARNING: Value of X must be 1000, 10000 or 100000 when requesting columns that mention X. 
						 The requested column will be missing. ;
					%end;
			%end;
		%end;
	   run;
	%end; /*end of custom colums*/
	
		/*Create an empty dataset with default label*/
		data defaultcolumns;
			format variable $32. description $100. ;
	 		variable = "Npts"; description = "New Users"; output;
			variable = "DenNumPts"; description = "Eligible^nMembers^{super 1}"; output;
	 		variable = "Episodes"; description = "New Episodes"; output;
			variable = "tte"; description = "Days At Risk"; output;
	 		variable = "TTEdiv36525"; description = "Years at Risk"; output;
	 		variable = "AdjustedCodeCount"; description = "Adjusted Dispensings";  output;
	 		variable = "RawCodeCount"; description = "Raw Dispensings";  output;
	 		variable = "DaySupp"; description = "Days Supplied";  output;
			variable = "AmtSupp"; description = "Amount Supplied"; output;
			variable = "All_Events"; description = "All Events"; output;
			variable = "Eps_wEvents"; description = "New Episodes with an Event"; output;
	 		variable = "DenNumMemDays"; description = "Eligible^nMember-Days^{super 1}"; output;
	 		variable = "DenNumMemDaysdiv36525"; description = "Eligible^nMember^nYears^{super 1}"; output;
		run;
		
		data optionalcolumns;
			format variable $32. description $100.;
			%if %sysfunc(exist(infolder.&columns_table.)) %then %do;
	 		variable = "Npts/DenNumPts*"; description = "New Users/^n &factor1. Eligible Members^{super 1}"; output;
			%end;

			variable = "DaySupp/Episodes"; description = "Days Supplied/^n Episode"; output;
	 		variable = "AmtSupp/Episodes"; description = "Amount Supplied/^n Episodes"; output;
	 		variable = "AdjustedCodeCount/Npts"; description = "Adjusted Dispensing/^n User"; output;
	 		variable = "RawCodeCount/Npts"; description = "Raw Dispensings/^n User"; output;

	 		variable = "DaySupp/Npts";     description = "Days Supplied/^n User"; output;

     		variable = "DaySupp/AdjustedCodeCount"; description = "Days Supplied/^n Adjusted Dispensings"; output;
	 		variable = "AmtSupp/AdjustedCodeCount"; description = "Amount Supplied/^n Adjusted Dispensings"; output;
     		variable = "DaySupp/RawCodeCount"; description = "Days Supplied/^n Raw Dispensings"; output;
	 		variable = "AmtSupp/RawCodeCount"; description = "Amount Supplied/^n Raw Dispensings"; output;

			%if %sysfunc(exist(infolder.&columns_table.)) %then %do;
	 		variable = "Eps_wEvents/ttediv36525*"; description = "Episodes with Outcomes /^n&factor2. Member Years at Risk"; output;
    		variable = "Eps_wEvents / DenNumPts*"; description = "Episodes with Outcomes /^n&factor3. Eligible Members^{super 1}"; output;
			%end;

			variable = "Eps_wEvents/Npts"; description = "Episodes with Events/^n User"; output;
	 		variable = "Eps_wEvents/Episodes"; description = "Episodes with Events/^n Episode"; output;
		run;

		data allcolumns;
			 set defaultcolumns optionalcolumns;
			 format newvar $32.; newvar = compress(lowcase(variable));
		run;

		/*User requested columns must match to universe list of 11 optional columns */
		%if %sysfunc(exist(infolder.&columns_table.)) %then %do;
			proc sql;
				create table _&columns_table. as
			  	select distinct a.*, b.variable as defaultvar, b.description as defaultdesc
			  	from  &columns_table. a, allcolumns b
			  	where compress(lowcase(a.variable),"1000 10000 100000") = compress(lowcase(b.variable));
			quit;

			proc sql;
				  create table defaultcolumns_r as 
				  select compress(lowcase(variable)) as newvar format=$32., * from defaultcolumns where compress(lowcase(variable)) not in 
				  (select distinct compress(lowcase(variable)) from _&columns_table.);
			quit;

			data &columns_table.;
				set _&columns_table.
					defaultcolumns_r;
				if description = "" then description = defaultdesc;
			run;
		%end;

		/*Create format to map variables to labels*/
		data descfmt;
			 retain fmtname '$labelfmt' type 'C';
			 %if %sysfunc(exist(infolder.&columns_table.)) %then %do;
			 	set &columns_table. end = eof;
				start = newvar ;
			 %end;
				
			 /*if the user did not supply the columns table, then use the default columns list*/
			 %else %do;
			 	set defaultcolumns  end = eof;
				start = lowcase(compress(variable));
			 %end;
			 label  = description;
			 output;
			 if eof then do;
			 	 start = ' ';
				 hlo = 'o';
				 label = '';
			 	output;
			 end;
		run;

		proc format cntlin = descfmt library = work;
		run;

/************************************************************************************************************************************
*	3. Calculated vars and labels
*************************************************************************************************************************************/

	%macro calcvars_labels();			
		/*In years*/	
		if ^missing(tte) then ttediv36525 = round(tte/365.25,.1);
		if ^missing(DenNumMemDays) then DenNumMemDaysdiv36525 = round(DenNumMemDays/365.25, .1);
		%if %sysfunc(exist(infolder.&columns_table.)) %then %do;			
			%do var = 1 %to &numcustomvars.;
				%let variable = %scan(&customvars., &var., " ");
				%let newvar = %scan(&newcustomvars., &var.);
				%if %sysfunc(index(&variable., /)) %then %do;
					%let numerator = %scan(&variable., 1, "/");
					%let denominator = %sysfunc(compress(%scan(&variable, 2, "/"), "* 1000 10000 100000"));
						/*if the requested column has multiplication factor X*/
						%if %index(%lowcase(&variable.), *) %then %do;
							   %let y = %sysfunc(substr(&variable., %index(&variable, *)+1));
								%if &y. = 1000 or &y. = 10000 or &y. = 100000 %then %do;
									if ^missing(&numerator.) & &denominator. gt 0 then 
										&newvar. = round((&numerator./&denominator)*&y., .01);	
									else &newvar. = .;	
								%end;
								%else %do;
									&newvar. = .;
									%put WARNING: Value of X must be 1000, 10,000 or 100,000 when requesting columns that mention X. 
									  The requested column will be missing. ;
								%end;
						%end; /*end of X*/
						%else %do;
							if ^missing(&numerator.) and &denominator. gt 0 then 
							&newvar. = round((&numerator./&denominator.), .01);	
							else &newvar. = .;		
						%end;
					format &newvar. comma10.2;
				%end; /*end of loop for calculated columns*/
			%end; /*end of all variables*/
		 %end;
		 /*labels for stratification variables*/
		 %if "&statelevel." = "state" %then %do;
			if state in ("Invalid", "Missing") and episodes lt 1 then delete;
		%end;
			label sex = "Sex" 
				  Agegroup = "Age Group"
				  year = "Year"
				  month = "Month"
				 %if "&racelevel." = "race" %then %do;
				  race = "Race"
				  %end;
				  %if "&statelevel." = "state" %then %do;
				   state = "State"
				   %end;
				  %if "&hhslevel." = "hhs_reg" %then %do;
				    hhs_reg = "HHS Region"
					%end;
				  %if "&cblevel." = "cb_reg" %then %do;
				   cb_reg = "Census Region"
				   %end;
				  %if %index(%lowcase(&zip3level), zip3 ) %then %do;
				   	zip3 = "3-Digit Zip/State"
				  %end;
				   %if "&zip_uncertain." = "zip_uncertain" %then %do;
				   zip_uncertain = "Zip Uncertain"
				   %end;
				   %if "&hispaniclevel." = "hispanic" %then %do;
				   hispanic = "Hispanic"
				   %end;

			/*covariate*/
			%if %str(&covarlist) ne %str() %then %do;
				%do c = 1 %to %sysfunc(countw(&covarlist.));
					%let w = %lowcase(%scan(&covarlist., &c.));
						%let covnum = %substr(&w., 6);
						covar&covnum. = "&&&covar&covnum."
				%end;
			%end;
				;
	%mend calcvars_labels;	

/************************************************************************************************************************************
*	4. Translate levels to names for display. 
************************************************************************************************************************************/	

	/*customized titles for stratification*/
	%macro titles();
		%if %length(&customtitle.) > 0 %then %do; 
				%let labeltitle = %bquote(&customtitle. );
			%end;
			%else %let labeltitle =;;
				%if "%quote(&category.)" eq "" %then %do;
					%let strat = Overall;
			%end;
			%else %do;
				%let numcats = %sysfunc(countw(&category.));
				%if &numcats. > 0 %then %do;
					%let strat=;
					%do c = 1 %to &numcats.;
						%if &numcats. = 1 %then %do;
							%let strat = %quote(&category.);
						%end;
						%else %do;
							%if &c. = 1 %then %do;
								%let strat = %scan(%quote(&category.), &c.);
							%end;
							%else %if &c. = 2 and &numcats. eq 2 %then %do;
								%let strat = &strat and %scan(%quote(&category.), &c.);
							%end;
							%else %if &c. = &numcats. and &numcats. gt 2 %then %do;
								%let strat = &strat, and %scan(%quote(&category.), &c.);
							%end;
							%else %do;
								%let strat = &strat, %scan(%quote(&category.), &c.);
							%end;
						%end;
					%end;
					/*Change Zip3 to 3-Digit Zip/State, Agegroup to Age Group and zip_uncertain to Zip Uncertain, HHS_reg to HHS Region, CB_reg to Census Regino*/
					%let strat = %sysfunc(tranwrd(%bquote(%sysfunc(tranwrd(%bquote(&strat.), Zip3, %bquote(3-Digit Zip/State)))), Agegroup, %bquote(Age Group))); 
					%let strat = %sysfunc(tranwrd(%bquote(%sysfunc(tranwrd(%bquote(&strat.), Hhs_reg, %bquote(HHS Region)))), Cb_reg, %bquote(Census Region)));
					%let strat = by %sysfunc(tranwrd(%bquote(&strat.), Zip_uncertain, %bquote(Zip Uncertain)));

					/*Change covar# to covariate label*/
					%if %index(%bquote(&strat.),Covar) >0 %then %do;
						%do c = 1 %to %sysfunc(countw(%bquote(&strat.)));
							%let w = %scan(%bquote(&strat.), &c.);

							%if %index(&w., Covar)> 0 %then %do;
								%let strat=%sysfunc(tranwrd(%bquote(&strat.), &w., %bquote(&&&w.))); 
							%end;
						%end;
					%end;

					%put strat ====>&strat.;
				%end;
			%end;
	%mend titles;			

/************************************************************************************************************************************
* 	5. Prepare final summary datasets.
************************************************************************************************************************************/	

		/*variables that are need to excluded from type1 file*/
		%create_comma_charlist(inlist=&type1exclude., outlist=type1excludelist);

		/*create comma list for class variables*/
		%create_comma_charlist(inlist=&classvars., outlist=classlist);

		/*for aggregated table*/
			data agg_dps_summ;
		  		set agg_dps_t&type._summ;
		  		%calcvars_labels();					
			run;
			
			/*get all the continous variables in the dataset*/
			proc contents data = agg_dps_summ out = varlist (keep = name label) noprint;
			run;
   			data varlist;
   	  			set varlist;
	   				if lowcase(name) not in (&rmvarlist., "numvisits", "ccielixgrp")
					and upcase(name) not in  (&classlist.) 
					and substr(lowcase(name),1,3) ne 'cov'
					%if &type. = 1 %then
					and upcase(name) not in (&type1excludelist.);
					;
					/*order in which the variables need to be displayed*/
					format varorder 8.0;
					varorder = put(compress(lowcase(name)), $varorderfmt.);
		    run;
			proc sort data = varlist;
				by varorder;
			run;
			proc sql noprint; 
     			select name into: varlistagg separated by ' ' 
				from varlist;
				select name into: varlistagg_nodenom separated by ' ' 
				from varlist
				where index(lowcase(name), 'dennum') = 0;
			quit;
				
			%do l = 1 %to %sysfunc(countw(&stratify_by_level.));
				%let level = %scan(&stratify_by_level., &l.);
				data _null_;
					category = put("%scan(&stratify_by_level., &l.)", $levelfmt.);
					call symputx("category", category);					
				run;

				%if %index(%lowcase(&category.), agegroup ) %then %do;
					%let category = %sysfunc(tranwrd(%quote(&category.), Agegroup, AgegroupNum Agegroup));
				%end; 

				/*For zip3, do not display rows where episodes are 0*/
				proc summary data = agg_dps_summ nway missing;	
					class combinegrouplabel level %quote(&category.);
					var &varlistagg.;
					where level = "%scan(&stratify_by_level., &l.)" 
						%if %index(%lowcase(&category.), zip3 ) %then %do; and episodes gt 0 %end;
						;
					output out = agg_dps_summ&level. (drop = _:) sum=;
				run;

				proc transpose data = agg_dps_summ&level. out = trans_dps_summ&level. (rename = _name_ = variable);
						by  combinegrouplabel level %quote(&category.);
						var &varlistagg.;
				run;

				data trans_dps_summ&level.; set trans_dps_summ&level.;
						format _label_ $100.;
						_label_ = put(compress(lowcase(variable)), $labelfmt.);
				run;

				proc sort data = trans_dps_summ&level.;
		 				by  combinegrouplabel level %quote(&category.);
				run;

				proc transpose data = trans_dps_summ&level. out = agg_dps_summ&level.;
					by combinegrouplabel level %quote(&category.) ;
					var col1;
					id variable;
					idlabel _label_;
				run; 

				proc sql;
		 			create table _agg_dps_summ&level. as
		 			select a.*, b.header, b.group1, b.grouplabel, b.order
		 			from agg_dps_summ&level. (drop = _name_ ) a, &groupfile. b
		 			where a.combinegrouplabel = b.combinegrouplabel;
				quit;

				proc sort data = _agg_dps_summ&level. ;
					by order %quote(&category.) ;
				run;						
			%end;

/************************************************************************************************************************************
* 	6. Add titles to table of contents
************************************************************************************************************************************/	

		/*counter for the summary table*/
		%let sumcount = 0;
		%if "%upcase(&Output_baselinetable.)" = "Y" %then
		%let sumcount = 1;
		%do l = 1 %to %sysfunc(countw(&stratify_by_level.));
			%let level = %scan(&stratify_by_level., &l.);			
			data _null_;
				category = put("%scan(&stratify_by_level., &l.)", $levelfmt.);
				call symputx("category", category);
			run;
			data tocagg; 
					length tables $10 caption $500;
					tables = "Table %eval(&l.+ &sumcount.)";
					%titles();
					 caption = "Summary of &&labeltitle.in the Sentinel Distributed Database between &startfollowup. and &enddate. &&strat.";
			run;
			%if &l. = 1 %then %do;
				data toc;
					set tocagg;
				run;
			%end;
			%else %do;
				proc append data = tocagg base = toc force; run;
			%end;
		%end;

		/*Clean up work files*/
		proc datasets lib=work nowarn nolist noprint;
			delete agg_dp: combine: group1: trans_:; 
		quit;

	%put =====> END MACRO: ms_t1t2table v1.3;

%mend ms_t1t2table;
